/*
 * Mandel by Rob Swiston and Chuck Simmons
 * Copyright (C) 1989, 1990 by Rob Swiston and Chuck Simmons
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 1 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * This is the glue that holds the server side of the mandelbrot
 * program together.  We set up a listener process that will listen
 * for connections.  In response to a connection, we fork off a child
 * process that will service the client.
 */

#include <signal.h>
#include <stdio.h>
#include "mandel.h"
#include "net.h"

#ifndef SIGCLD
# define SIGCLD SIGCHLD /* make the sequent happy */
#endif

void
usage (name)
char *name;
{
	(void) fprintf (stderr, "%s: Usage %s port\n", name, name);
	exit (1);
}

/*
 * Clean up after a dead child.
 */

void
cleanup ()
{
	int stat;

	wait (&stat);
}

int
main (argc, argv)
int argc;
char **argv;
{
	int port;
	int sock;

	if (argc != 2) usage (argv[0]);

	port = atoi (argv[1]);
	if (port <= 0) usage (argv[0]);

	/* Set up a signal handler to clean up after dead children. */
	(void) signal (SIGCLD, cleanup);

	/* Start up the listener process, which will fork in
	 * response to each new connection, returning the socket
	 * that was created.
	 */
	sock = net_slisten (port);
	if (sock == -1) {
		perror ("mserver: net_slisten failed");
		exit (1);
	}

	net_server (sock); /* service the client */
	return 0;
}
	

